package com.ruoyi.invest.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.invest.mapper.TStudyInformationMapper;
import com.ruoyi.invest.domain.TStudyInformation;
import com.ruoyi.invest.service.ITStudyInformationService;

/**
 * 研究资料管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-02-23
 */
@Service
public class TStudyInformationServiceImpl implements ITStudyInformationService 
{
    @Autowired
    private TStudyInformationMapper tStudyInformationMapper;

    /**
     * 查询研究资料管理
     * 
     * @param id 研究资料管理主键
     * @return 研究资料管理
     */
    @Override
    public TStudyInformation selectTStudyInformationById(String id)
    {
        return tStudyInformationMapper.selectTStudyInformationById(id);
    }

    /**
     * 查询研究资料管理列表
     * 
     * @param tStudyInformation 研究资料管理
     * @return 研究资料管理
     */
    @Override
    public List<TStudyInformation> selectTStudyInformationList(TStudyInformation tStudyInformation)
    {
        return tStudyInformationMapper.selectTStudyInformationList(tStudyInformation);
    }

    /**
     * 新增研究资料管理
     * 
     * @param tStudyInformation 研究资料管理
     * @return 结果
     */
    @Override
    public int insertTStudyInformation(TStudyInformation tStudyInformation)
    {
        tStudyInformation.setCreateTime(DateUtils.getNowDate());
        return tStudyInformationMapper.insertTStudyInformation(tStudyInformation);
    }

    /**
     * 修改研究资料管理
     * 
     * @param tStudyInformation 研究资料管理
     * @return 结果
     */
    @Override
    public int updateTStudyInformation(TStudyInformation tStudyInformation)
    {
        tStudyInformation.setUpdateTime(DateUtils.getNowDate());
        return tStudyInformationMapper.updateTStudyInformation(tStudyInformation);
    }

    /**
     * 批量删除研究资料管理
     * 
     * @param ids 需要删除的研究资料管理主键
     * @return 结果
     */
    @Override
    public int deleteTStudyInformationByIds(String[] ids)
    {
        return tStudyInformationMapper.deleteTStudyInformationByIds(ids);
    }

    /**
     * 删除研究资料管理信息
     * 
     * @param id 研究资料管理主键
     * @return 结果
     */
    @Override
    public int deleteTStudyInformationById(String id)
    {
        return tStudyInformationMapper.deleteTStudyInformationById(id);
    }

    /**
     * 批量删除研究资料管理
     *
     * @param ids 需要删除的研究资料管理主键
     * @return 结果
     */
    @Override
    public int updateTStudyInformationByIds(String[] ids) {
        return tStudyInformationMapper.updateTStudyInformationByIds(ids);
    }
}
