package com.ruoyi.web.controller.invest;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.enums.FileType;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.tool.domain.TUnifyFile;
import com.ruoyi.tool.service.ITUnifyFileService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.invest.domain.TStudyInformation;
import com.ruoyi.invest.service.ITStudyInformationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 研究资料管理Controller
 * 
 * @author ruoyi
 * @date 2024-02-26
 */
@Api(tags = "研究资料管理")
@RestController
@RequestMapping("/study/gen")
public class TStudyInformationController extends BaseController
{
    @Autowired
    private ITStudyInformationService tStudyInformationService;

    @Autowired
    private ITUnifyFileService tUnifyFileService;

    @Autowired
    private ISysDictDataService dictDataService;

    /**
     * 查询研究资料管理列表
     */
    @ApiOperation("查询研究资料管理列表")
    @PreAuthorize("@ss.hasPermi('study:gen:list')")
    @GetMapping("/list")
    public TableDataInfo list(TStudyInformation tStudyInformation)
    {
        startPage();
        tStudyInformation.setCreateBy(getNickName());//默认登陆人权限
        List<TStudyInformation> list = tStudyInformationService.selectTStudyInformationList(tStudyInformation);
        return getDataTable(list);
    }

    /**
     * 导出研究资料管理列表
     */
    @ApiOperation("导出研究资料管理列表")
    @PreAuthorize("@ss.hasPermi('study:gen:export')")
    @Log(title = "研究资料管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TStudyInformation tStudyInformation)
    {
        tStudyInformation.setCreateBy(getNickName());//默认登陆人权限
        List<TStudyInformation> list = tStudyInformationService.selectTStudyInformationList(tStudyInformation)
                .stream().map(n -> {
                    n.setContractType(dictDataService.selectDictLabel("file_type",n.getContractType()));
                    return n;
                })
                .collect(Collectors.toList());
        ExcelUtil<TStudyInformation> util = new ExcelUtil<TStudyInformation>(TStudyInformation.class);
        util.exportExcel(response, list, "研究资料管理数据");
    }

    /**
     * 获取研究资料管理详细信息
     */
    @ApiOperation("获取研究资料管理详细信息")
    @PreAuthorize("@ss.hasPermi('study:gen:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tStudyInformationService.selectTStudyInformationById(id));
    }

    /**
     * 新增研究资料管理
     */
    @ApiOperation("新增研究资料管理")
    @PreAuthorize("@ss.hasPermi('study:gen:add')")
    @Log(title = "研究资料管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TStudyInformation tStudyInformation)
    {
        tStudyInformation.setId(IdUtils.fastSimpleUUID());
        tStudyInformation.setCreateBy(getNickName());
        // todo 保存附件信息
        tUnifyFileService.insertTUnifyFileList(tStudyInformation.getListFile(),
                null,
                tStudyInformation.getId(),
                String.valueOf(FileType.GEN.ordinal()),
                getNickName());

        return toAjax(tStudyInformationService.insertTStudyInformation(tStudyInformation));
    }

    /**
     * 修改研究资料管理
     */
    @ApiOperation("修改研究资料管理")
    @PreAuthorize("@ss.hasPermi('study:gen:edit')")
    @Log(title = "研究资料管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TStudyInformation tStudyInformation)
    {
        // todo 保存附件信息
        tUnifyFileService.insertTUnifyFileList(tStudyInformation.getListFile(),
                null,
                tStudyInformation.getId(),
                String.valueOf(FileType.GEN.ordinal()),
                getNickName());
        
        return toAjax(tStudyInformationService.updateTStudyInformation(tStudyInformation));
    }

    /**
     * 删除研究资料管理
     */
    @ApiOperation("删除研究资料管理")
    @PreAuthorize("@ss.hasPermi('study:gen:remove')")
    @Log(title = "研究资料管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tStudyInformationService.updateTStudyInformationByIds(ids));
    }
}
